@@ -7,9 +7,10 @@ from flask_sqlalchemy import SQLAlchemy
 from notejob.center.app.scheduler import CuBackgroundScheduler
 from notejob.center.config import config_dict
 
+from .base import db
+
 scheduler = APScheduler(scheduler=CuBackgroundScheduler())
 
-db = SQLAlchemy()
 
 formatter = logging.Formatter("[%(asctime)s][%(filename)s:%(lineno)d][%(levelname)s][%(thread)d] - %(message)s")
 
@@ -48,7 +49,7 @@ def create_app(config_name):
 
     scheduler.app = app
     db.init_app(app)
-    db.create_all()
+    # db.create_all()
     scheduler.init_app(app)
     scheduler.start()
 
